<div align="center">

<h1>Django Lookbook</h1>

<p>Empower your Django development with this pluggable app for creating a robust component library. Includes preview system, documentation engine, and parameter editor for building modular UI effortlessly.</p>

<p><strong><a href="https://django-lookbook.readthedocs.io/en/latest/">Documentation</a> &nbsp;|&nbsp; <a href="https://saashammer.com/lookbook/">Demo site</a></strong></p>

<p><a href="https://pypi.org/project/django-lookbook/"><img src="https://badge.fury.io/py/django-lookbook.svg" alt="Pypi version"></a>
<a href="https://github.com/rails-inspire-django/django-lookbook/actions/workflows/runtests.yml"><img src="https://github.com/rails-inspire-django/django-lookbook/actions/workflows/runtests.yml/badge.svg" alt="CI status"></a></p>

</div>

![Django Lookbook UI](.github/assets/lookbook_ui.png)
